#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2023/3/22 15:20
# @Author  : unclear
# @File    : __init__.py.py
# @Software: PyCharm
__version__ = "0.0.1"

from testpg import shell, src

__all__ = [
    "__version__",
    "shell",
    "src"
]
