#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2023/3/22 15:20
# @Author  : unclear
# @File    : __init__.py.py
# @Software: PyCharm
from testpg.shell.usage import run

__all__ = [
    "run"
]