#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2023/3/22 15:34
# @Author  : unclear
# @File    : __init__.py.py
# @Software: PyCharm
from package_name.src import demo

__all__ = [
    "demo"
]